@@ -203,4 +203,5 @@ def configure(config):
     config.add_route('extjs-l10n', '/extjs-l10n')
     config.add_route('scripts', '/scripts')
 
-    config.scan('metapensiero.extjs.desktop')
+    config.scan('metapensiero.extjs.desktop',
+                ignore='metapensiero.extjs.desktop.scripts.extjs_deps')
